@@ -12,7 +12,7 @@
 ##' the number of additional associations to be added instead of \code{rel}.
 ##' @param omitrel if \code{k} greater than 1, this boolean defines wether to
 ##' omit candidates containing \code{rel} from the output
-##' @param \dots Additional arguments to be passed to the low level functions
+##' @param \dots Additional arguments to be passed to the lower-level functions
 ##' @author Klaus K. Holst
 ##' @seealso \code{\link{compare}}, \code{\link{modelsearch}}
 ##' @export
@@ -26,7 +26,7 @@ equivalence <- function(x,rel,tol=1e-3,k=1,omitrel=TRUE,...) {
   if (length(myvars)!=2) stop("Two variables only")
   x0 <- Model(x)
   cancel(x0) <- rel
-  e0 <- estimate(x0,data=model.frame(x),weight=Weight(x),estimator=x$estimator,...)
+  e0 <- estimate(x0,data=model.frame(x),weights=Weights(x),estimator=x$estimator,...)
   if (k!=1) {
     p0 <- coef(x)
     p0[] <- 0
